==> resin-3.1.13-src.tar.gz: resin-3.1.13/modules/resin/src/com/caucho/amber/field/MapElementField.java <==
/*
 * Copyright (c) 1998-2008 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.amber.field;

import com.caucho.amber.table.Column;
import com.caucho.amber.type.EntityType;
import com.caucho.java.JavaWriter;
import com.caucho.log.Log;
import com.caucho.util.L10N;

import java.io.IOException;
import java.util.ArrayList;
import java.util.logging.Logger;

/**
 * Configuration for a bean's field
 */
public class MapElementField extends AssociationField
  implements MapField {
  private static final L10N L = new L10N(MapElementField.class);
  protected static final Logger log = Log.open(MapElementField.class);

  private ArrayList<Column> _indexColumns;
  
  public MapElementField(EntityType entityType)
  {
    super(entityType);
  }

  /**
   * Sets the index columns.
   */
  public void setIndexColumns(ArrayList<Column> columns)
  {
    _indexColumns = columns;
  }

  /**
   * Sets the index columns.
   */
  public ArrayList<Column> getIndexColumns()
  {
    return _indexColumns;
  }

  /**
   * Generates the select clause.
   */
  public String generateLoadSelect(String id)
  {
    return null;
  }

  /**
   * Generates the set property.
   */
  public void generateGetterMethod(JavaWriter out)
    throws IOException
  {
  }
}

==> resin-4.0.66-src.tar.gz: resin-4.0.66/modules/resin/src/com/caucho/amber/field/MapElementField.java <==
/*
 * Copyright (c) 1998-2018 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.amber.field;

import com.caucho.amber.table.AmberColumn;
import com.caucho.amber.type.EntityType;
import com.caucho.java.JavaWriter;
import com.caucho.util.L10N;

import java.io.IOException;
import java.util.ArrayList;
import java.util.logging.Logger;

/**
 * Configuration for a bean's field
 */
public class MapElementField extends AssociationField
  implements MapField {
  private static final L10N L = new L10N(MapElementField.class);
  protected static final Logger log
    = Logger.getLogger(MapElementField.class.getName());

  private ArrayList<AmberColumn> _indexColumns;
  
  public MapElementField(EntityType entityType)
  {
    super(entityType);
  }

  /**
   * Sets the index columns.
   */
  public void setIndexColumns(ArrayList<AmberColumn> columns)
  {
    _indexColumns = columns;
  }

  /**
   * Sets the index columns.
   */
  public ArrayList<AmberColumn> getIndexColumns()
  {
    return _indexColumns;
  }

  /**
   * Generates the select clause.
   */
  public String generateLoadSelect(String id)
  {
    return null;
  }

  /**
   * Generates the set property.
   */
  public void generateGetterMethod(JavaWriter out)
    throws IOException
  {
  }
}
